=======
Fitting
=======

Fitting
-------

For fitting a model (composed from a combination of ``Galaxy`` and / or ``Plane`` objects) to a
dataset.

.. currentmodule:: autogalaxy

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   FitImaging
   FitInterferometer